@@ -19,7 +19,7 @@ from .visualization import (
 )
 
 
-def eval_model(model, ds, repeat, mlb, output_p, marker):
+def eval_model(model, ds, repeat, mlb, output_p, marker=""):
     tag_stat = rawdata_stat(ds)
     tag_stat.to_csv(f"{output_p}/{marker}_{repeat}_data_stat.csv")
     fig = plot_tag_stat(tag_stat)
